*** create the year constraints for the sample periods
local c1 year >= 1870 & (year <1935 | year >1945)  & (year <1910 | year >1919) & year<2009

*** Sample period names
local p1 full
local t1 Full sample: 1870-2008


* Controls
		local rhs6a /// * RHS 6 variables
		dlrgdp   dlcpi   dlriy   stir ltrate cay     ///
	    ldlrgdp   ldlcpi   ldlriy   lstir lltrate lcay 

		local c_rhs6a /// * RHS 6 variables when centered
		c_dlrgdp c_dlcpi c_dlriy c_stir c_ltrate c_cay  ///
		c_ldlrgdp c_ldlcpi c_ldlriy c_lstir c_lltrate c_lcay 
		


* Prepare LPs
eststo clear
local irvars1 lrgdp 

label var pk_norm "Norm. rec."
label var pk_fin "Fin. rec"

cap drop pk
gen pk=pk_fin+pk_norm
replace pk_fin=. if pk==0

local types pk_fin

foreach y of local irvars1 {
	forvalues j=1/1{
		
		cap drop cap_fin
		cap drop cap_norm
		
		*******************************************************************************
		* 1. determine sample
		 reg `y'1 `types' lev_1 `rhs6a' ///
			if `c`j'' & war==0, cluster(iso)
			capture drop xsample
			qui gen xsample = e(sample)
		
		*DEMEANING***********************
		* center RHS6 regressors for estimation sample
		capture drop `c_rhs6a'
		center  `rhs6a'  if xsample==1
		center  `c_rhs6a'  if xsample==1 & pk_fin  ==1, inplace  
		center  `c_rhs6a'  if xsample==1 & pk_fin  ==0, inplace  
		

		qui reg lev_1 i.ccode          	if xsample ==1 & pk_norm ==1
		predict cap_norm		    	if xsample ==1 & pk_norm ==1 , resid
		replace cap_norm = 0       		if xsample ==1 & pk_norm ==0
		qui reg lev_1 i.ccode          	if xsample ==1 & pk_fin  ==1
		predict cap_fin 		    	if xsample ==1 & pk_fin  ==1 , resid 
		replace cap_fin = 0        		if xsample ==1 & pk_fin  ==0
		
		
		label var cap_fin "Financial x capital ratio"
		label var cap_norm "Recession x capital ratio"
		
		local vars pk_fin cap_fin cap_norm 
		local report pk_fin cap_norm cap_fin
		
		
		capture drop Recession
		gen Recession = 1 // constant term
		label var Recession "Norm. rec. "
		
		* RHS of LP's
		local local1 Recession `vars' `c_rhs6a'
	
		* keep in table
		local n1 `report'
		
		capture drop lrgdp99
		qui gen lrgdp99 = lrgdp1+lrgdp2+lrgdp3+lrgdp4+lrgdp5
		label var lrgdp99 "Sum"
		
		* 2. Run LPs
		forvalues k=1/1{
			foreach i of numlist 1/5 99 {
				
				ivreg2 `y'`i' `local`k'' cendum1-cendum16  ///
					if xsample==1, cluster(iso year) nocons
					
					test pk_fin=Recession
					estadd scalar PvalueNF = r(p)
					test cap_fin=cap_norm
					estadd scalar PvalueCap = r(p)
					eststo LPa`i'`j'`k'
}
			
			esttab LPa1`j'`k'  LPa2`j'`k'  LPa3`j'`k'  LPa4`j'`k'  LPa5`j'`k' LPa99`j'`k' ///
				using "../tables/Table_A27.tex", replace ///
				 title(Table: Local Projections of real GDP per capita for normal and financial recessions. Including macroeconomic controls. `t`j''. 2-way clustered SEs)  nonotes ///
				se r2 keep(Recession pk_fin cap_norm cap_fin) order(Recession pk_fin cap_norm cap_fin) b(2) se(2) sfmt(2) wrap ///
				indicate(Controls=c_dlrgdp) ///
				obslast num label star(* 0.10 ** 0.05 *** 0.01) scalars("PvalueNF Normal=Financial (average)" "PvalueCap Normal=Financial (Cap. Ratio)")
}
		
			eststo clear	
}		
}
graph drop _all
		

