*** create the year constraints for the sample periods
local c1 year >= 1870 & (year <1935 | year >1945)  & (year <1910 | year >1919) & year<2009

*** Sample period names
local p1 full
local t1 Full sample: 1870-2008

	local rhs6a /// * RHS 6 variables
		dlrgdp   dlcpi   dlriy   stir   ltrate   cay   ///
		ldlrgdp   ldlcpi   ldlriy   lstir   lltrate   lcay 

		local c_rhs6a /// * RHS 6 variables when centered
		c_dlrgdp c_dlcpi c_dlriy c_stir c_ltrate c_cay ///
		c_ldlrgdp c_ldlcpi c_ldlriy c_lstir c_lltrate c_lcay 


eststo clear
local irvars1 lrgdp 

label var pk_norm "Norm. rec."
label var pk_fin "Fin. rec."

cap drop pk
gen pk=pk_fin+pk_norm
replace pk_fin=. if pk==0

local types pk_fin
local vars pk_finhi pk_finlo 

foreach y of local irvars1 {
	forvalues j=1/1 {
		
		foreach s of local vars{     // variables for graphs
			cap drop G`s'`j'
			qui gen G`s'`j'= 0 if _n==1
			}
		cap drop Gconstant`j'
		cap drop up1constant`j'
		cap drop dn1constant`j'
		qui gen Gconstant`j'=0 if _n==1
		qui gen up1constant`j'= 0 if _n==1
		qui gen dn1constant`j'= 0 if _n==1
			
		*Determine sample
		qui reg `y'1 `types' `rhs6a' lev_1 cendum1-cendum16 ///
			if `c`j'' & war==0, cluster(iso)
			capture drop xsample
			qui gen xsample = e(sample)
		
		
		*DEMEANING controls***********************
		capture drop `c_rhs6a'
		center  `rhs6a' if xsample==1
		center  `c_rhs6a' if xsample==1 & pk_fin==1, inplace  // re-center by bin
		center  `c_rhs6a' if xsample==1 & pk_fin==0, inplace  // re-center by bin

		
			* hi/lo capital dummies
			qui capture drop pk_finhi pk_finlo 
			foreach v of local types{
				qui gen `v'lo=0 if lev_1!=.
				qui gen `v'hi=0 if lev_1!=.
					qui sum lev_1 if `v'==1 & xsample==1, d
					qui replace `v'lo=`v' if lev_1<=r(mean) & lev_1!=.
					qui replace `v'hi=`v' if lev_1>r(mean) & lev_1!=.
			}
			local vars pk_finhi pk_finlo 
			local report pk_finhi pk_finlo
			la var pk_finlo "Financial, low capital ratio"
			la var pk_finhi "Financial, high capital ratio"
			
			
		capture drop Recession
		gen Recession = 1 // constant term

		* RHS of LP's
		local local1 Recession `vars' `c_rhs6a'
	
		* keep in table
		local n1 Recession `report'
		
		capture drop lrgdp99
		qui gen lrgdp99 = lrgdp1+lrgdp2+lrgdp3+lrgdp4+lrgdp5
		label var lrgdp99 "Sum"
		
		
		* 2. LPs with controls
		forvalues k=1/1{
			foreach i of numlist 1/5 99  {
				
				ivreg2 `y'`i' `local`k'' cendum1-cendum16  ///
					if xsample==1, cluster(iso year) nocons
					
					test pk_finlo=pk_finhi 
					estadd scalar Pvalue = r(p)

					eststo LPa`i'`j'`k'
					estadd scalar Recession = _b[Recession]
					estadd scalar Constant_se = _se[Recession]
				
				foreach s of local vars {
					qui replace G`s'`j' = _b[Recession] + _b[`s'] if _n == `i'+1
				}
				qui replace Gconstant`j'= _b[Recession] if _n == `i'+1
				qui replace up1constant`j' = _b[Recession] + 1.645*_se[Recession] if _n == `i'+1
				qui replace dn1constant`j' = _b[Recession] - 1.645*_se[Recession] if _n == `i'+1
					}
			
			esttab LPa1`j'`k'  LPa2`j'`k'  LPa3`j'`k'  LPa4`j'`k'  LPa5`j'`k' LPa99`j'`k' ///
				using "../tables/Table_A26.tex", replace ///
				title(Table: Local Projections of real GDP per capita for normal and financial recessions. `t`j''. Macroeconomic controls included. 2-way clustered SEs.) nonotes ///
				se r2 keep(`n`k'') b(2) se(2) sfmt(2) wrap ///
				indicate(Controls=c_dlrgdp) ///
				obslast num label star(* 0.10 ** 0.05 *** 0.01) scalars("Pvalue High=Low (Capital Ratio)")
		
}
}			
}


		
		
