*** create the year constraints for the sample periods
local c1 year >= 1870 & (year <1935 | year >1945)  & (year <1910 | year >1919) & year<2009

local p1 full
local t1 Full sample: 1870-2008

eststo clear
local irvars1 rprv

label var pk_norm "Norm. rec."
label var pk_fin "Fin. rec."

cap drop pk
gen pk=pk_fin+pk_norm
replace pk_fin=. if pk==0

local types pk_fin
local vars pk_finhi pk_finlo

foreach y of local irvars1 {
	forvalues j=1/1 {
		
		foreach s of local vars{     // variables for graphs
			cap drop G`s'`j'
			qui gen G`s'`j'= 0 if _n==1
			}
		cap drop Gconstant`j'
		cap drop up1constant`j'
		cap drop dn1constant`j'
		qui gen Gconstant`j'=0 if _n==1
		qui gen up1constant`j'= 0 if _n==1
		qui gen dn1constant`j'= 0 if _n==1
			
*******************************************************************************
		* Determine sample
		qui reg `y'5 `types' lev_1 ///
			if `c`j'' & war==0, cluster(iso)
			capture drop xsample
			qui gen xsample = e(sample)
			

			* hi/lo interactions with lev demeaned by type
			qui capture drop pk_finhi pk_finlo 
			foreach v of local types{
				qui gen `v'lo=0
				qui gen `v'hi=0
					qui sum lev_1 if `v'==1 & xsample==1
					qui replace `v'lo=`v' if lev_1<=r(mean) & lev_1!=.
					qui replace `v'hi=`v' if lev_1>r(mean) & lev_1!=.
			}

			local vars pk_finhi pk_finlo
			local report pk_finhi pk_finlo
			la var pk_finlo "Financial, low capital ratio"
			la var pk_finhi "Financial, high capital ratio"
			
	
		
		capture drop Recession
		gen Recession = 1 // constant term

		* RHS of LP's
		local local1 Recession `vars'  
	
		* keep in table
		local n1 Recession `report'
		
		
		* 2. LPs with controls
		forvalues k=1/1{
			foreach i of numlist 1/5 {
				
				reg `y'`i' `local`k'' cendum1-cendum16 ///
					if xsample==1, cluster(iso) nocons
					
					test pk_finlo=pk_finhi 
					estadd scalar Pvalue = r(p)

					eststo LPa`i'`j'`k'
					estadd scalar Recession = _b[Recession]
					estadd scalar Constant_se = _se[Recession]
				
				foreach s of local vars {
					qui replace G`s'`j' = _b[Recession] + _b[`s'] if _n == `i'+1
				}
				qui replace Gconstant`j'= _b[Recession] if _n == `i'+1
				qui replace up1constant`j' = _b[Recession] + 1.645*_se[Recession] if _n == `i'+1
				qui replace dn1constant`j' = _b[Recession] - 1.645*_se[Recession] if _n == `i'+1
					}
				esttab LPa1`j'`k'  LPa2`j'`k'  LPa3`j'`k'  LPa4`j'`k'  LPa5`j'`k' ///
				using "../tables/Table_A29.tex", replace ///
				title(Table: Local Projections of real private credit per capita for normal and financial recessions. `t`j''. Macroeconomic controls included. ) nonotes ///
				se r2  keep(`n`k'') b(2) se(2) sfmt(2) wrap ///
				obslast num label star(* 0.10 ** 0.05 *** 0.01) scalars("Pvalue High=Low (Capital Ratio)")

		}
		
			
		cap drop zero
		gen zero = 0 if _n <= 6
			
		capture drop Years
		gen Years = _n-1 if _n <= 6
				
		preserve
		
		keep if Years<=5
		
		twoway (rarea up1constant`j' dn1constant`j' Years, ///
			fcolor(gs12) lcolor(white) lpattern(solid)) /// 
			(line Gconstant`j' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///  
			(line Gpk_finlo`j' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
			(line Gpk_finhi`j' Years, lcolor(green) lpattern(longdash) lwidth(thick)) /// 
			(line zero Years, lcolor(black)), ///
			ylabel(-10(5)30, nogrid) graphregion(color(white)) plotregion(color(white)) ///
			ytitle("Percent (100x log)", size(medsmall)) xtitle("Year", size(medsmall)) ///
			legend(  pos(11) ring(0) col(1) region(ls(none)) order(2 4 3) label(2 "Normal recession") label(3 "Financial, low capital ratio") label(4 "Financial, high capital ratio")) ///	
			name(lp`y'`j', replace) scale(0.8)
				
			restore
			eststo clear	
			
		graph display , ysize(3) xsize(3) scale(1.2)
		graph export "../graphs/Figure_9a.pdf", replace
		graph export "../graphs/Figure_9a.eps", replace

	}
			
}


		
graph drop _all
		
