********************************************************************************
* BANK CAPITAL REDUX: SOLVENCY, LIQUIDITY, AND CRISIS
* Jorda, Richter, Schularick and Taylor
********************************************************************************

clear 
set more off

* Björn
cap cd "C:\Users\brich\sciebo\Björn\Bank Capital\BankCapitalRedux_STATA_29_06_2020\programs"

* Alan
cap cd "/Users/amtaylor/Google Drive/JST/BankCapitalRedux/Master/BankCapitalRedux_STATA_29_06_2020/programs"

capture log close
log using "../logs/Banks.log" , replace

* graph settings
set scheme s1color
graph set window fontface "Palatino"
graph set window fontfaceserif "Palatino"

********************************************************************************

do data							// loads and prepares data, setup

********************************************************************************
*Section 3: Description of Data

do data_tables					// generates summary tables for data description part

do data_figures					// generates figures for data description part

do data_around_crises			// behavior of variables around financial crises 

do data_binscatters				// binscatters how balance sheet ratios change during credit expansions

do data_crisis_bins				// Bar charts with crisis frequency and cost in quintiles of capital ratio distribution

********************************************************************************
*Section 4: Crisis Prediction

*Main Tables 4 and 5 and robustness (no controls, no FE, no US/UK, 2-way clustered SEs)

do probit_models
	
*Additional robustness tests from the online appendix

do probit_BVX							// probits using Baron, Verner and Xiong (2020) crisis dates 

do probit_subsamples					// probits split by deposit insurance

do probit_drop_variables 				// probits dropping one variable at the time from full model including credit growth and balance sheet ratios

do probit_large_banks 					// probits with leverage of largest banks

do probit_Italy							// probits with leverage dispersion measure in Italy
	
do probit_interactions					// probits with interaction of dloansgdp5 and hi/low capital ratio dummy 

do probit_country_decade_FE				// probits including country x decade FE

do probit_iv							// probit instrumental variable approach

********************************************************************************
*Section 5: Return predictability exercises
********************************************************************************

do return_predictability				// Baron and Xiong (2017) style return predictability

********************************************************************************
*Section 6: Local projections (role of capital in financial recessions)
********************************************************************************

do LP_prep				// prepares data for LPs, multiplies lev_1 by 100

*************Baseline LPs with and w/o controls*********************************

do LP_nocont 			// high vs low capital in financial recessions, no controls 
	
do LP_cont				// high vs low capital in financial recessions,  controls  (full sample)

do LP_cont_noGFC		// high vs low capital in financial recessions,  controls  (no GFC sample)
		
do LP_cont_dec 			// high vs low capital in financial recessions, controls include centered decade dummies
		
*************Continuous treatment, demeaned by country and bin (N/F)************

do LP_bins_demeaned 	// demeaned by country and type at the same time --> within country, continuous measure of capital

	
***********Real private credit as outcome**********************************************

do LP_nocont_rprv		// LPs using real private credit per capita as outcome variable, no controls

do LP_cont_rprv			// LPs using real private credit per capita as outcome variable, controls

***********Quartiles**********************************************

do LP_cont_quartiles 	// capital ratio quartiles, controls

do LP_nocont_quartiles 	// capital ratio quartiles, controls

***********2-way clustered SEs**********************************************

do LP_cont_2way				// high vs low capital in financial recessions, controls, 2-way clustered SEs

do LP_bins_demeaned_2way 	// capital demeaned by country and type, continuous measure, controls, 2-way clustered SEs

clear
set more on
log close

********************************************************************************

