*Produces graph of bank variables around financial crises (crisis year=0)

local c1 year >= 1870 
local p1 full

local pltd Loans/Deposits
local plev Capital/Assets
local ploansgdp Loans/GDP

local vars loansgdp lev ltd 

foreach var of local vars{

preserve

*empty variables
gen High=.
gen Low=.
gen median=.
gen p25=.
gen p75=.


*Define sample: leads and lags  + capital ratio available
reg l(1/4).`var' f(0/4).`var' lev_1 if crisisJST==1 & war==0 & `c1'
cap drop xsample
gen xsample=e(sample)


*split at sample median of capital ratio
egen median_lev = pctile(lev_1) if xsample==1, p(50)
gen hi_sample=.
replace hi_sample=0 if xsample==1 & lev_1<=median_lev 
replace hi_sample=1 if xsample==1 & lev_1>median_lev 

sort ccode year

forvalues j=0/4{
gen f`j'`var'=f`j'.`var'/`var'
}

forvalues j=0/4{
gen l`j'`var'=l`j'.`var'/`var'
}

*sample median with interquartile range 
forvalues j=0/4{
egen `var'_f`j'_median=pctile(f`j'`var') if xsample==1, p(50)
egen `var'_f`j'_p25=pctile(f`j'`var') if xsample==1, p(25) 
egen `var'_f`j'_p75=pctile(f`j'`var') if xsample==1, p(75) 
}

*median after crisis with high capital
forvalues j=0/4{
egen `var'_f`j'_High=pctile(f`j'`var') if hi_sample==1, p(50) 
}

*median after crisis with low capital
forvalues j=0/4{
egen `var'_f`j'_Low=pctile(f`j'`var') if hi_sample==0 , p(50)
}

*sample median with interquartile range 
forvalues j=0/4{
egen `var'_l`j'_median=pctile(l`j'`var') if xsample==1, p(50)
egen `var'_l`j'_p25=pctile(l`j'`var') if xsample==1, p(25) 
egen `var'_l`j'_p75=pctile(l`j'`var') if xsample==1, p(75) 
}

*median before crisis with high capital
forvalues j=0/4{
egen `var'_l`j'_High=pctile(l`j'`var') if hi_sample==1 , p(50)
}

*median before crisis with low capital
forvalues j=0/4{
egen `var'_l`j'_Low=pctile(l`j'`var') if hi_sample==0 , p(50)
}


local measures p25 p75 median High Low

foreach x of local measures{

*Fill in values 
forvalues j=0/4{
egen `var'_f`j'_`x'1=mean(`var'_f`j'_`x') 
replace `var'_f`j'_`x' = `var'_f`j'_`x'1
}
forvalues j=0/4{
egen `var'_l`j'_`x'1=mean(`var'_l`j'_`x') 
replace `var'_l`j'_`x' = `var'_l`j'_`x'1
}
}

*=so far data for all leads and lags a new variable in the crisis year
*=in order to plot it, use one specific crisis 

keep if iso=="USA" & year>=2003 & year<=2011
sort ccode year

gen sample_year=year-2007

foreach x of local measures{
replace `x'= `var'_l4_`x' if year==2003
replace `x'= `var'_l3_`x' if year==2004
replace `x'= `var'_l2_`x' if year==2005
replace `x'= `var'_l1_`x' if year==2006
replace `x'= `var'_f0_`x' if year==2007
replace `x'= `var'_f1_`x' if year==2008
replace `x'= `var'_f2_`x' if year==2009
replace `x'= `var'_f3_`x' if year==2010
replace `x'= `var'_f4_`x' if year==2011
}


keep if iso=="USA" & year>=2003 & year<=2011

label var sample_year "Year"

twoway  (rarea p25 p75 sample_year, ///
		fcolor(gs12) lcolor(white) lpattern(solid)) /// 
		(line median sample_year, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line High sample_year, lcolor(green) lpattern(longdash) lwidth(thick)) ///
		(line Low sample_year, lcolor(red) lpattern(shortdash) lwidth(thick)), ///
		graphregion(color(white)) plotregion(color(white)) ///
		xlabel(-4(1)4, nogrid) ylabel(0.7(0.1)1.2, nogrid) graphregion(color(white)) plotregion(color(white)) ///
		title("`p`var''", size(medlarge)) xtitle("Year", size(medlarge)) ///
		name(cris_`var', replace) legend(off)
		
restore
}

local vars ltd

foreach var of local vars{

preserve

*empty variables
gen High=.
gen Low=.
gen median=.
gen p25=.
gen p75=.


*Define sample: leads and lags  + capital ratio available
reg l(1/4).`var' f(0/4).`var' lev_1 if crisisJST==1 & war==0 & `c1'
cap drop xsample
gen xsample=e(sample)


*split at sample median of capital ratio
egen median_lev = pctile(lev_1) if xsample==1, p(50)
gen hi_sample=.
replace hi_sample=0 if xsample==1 & lev_1<=median_lev 
replace hi_sample=1 if xsample==1 & lev_1>median_lev 

sort ccode year

forvalues j=0/4{
gen f`j'`var'=f`j'.`var'/`var'
}

forvalues j=0/4{
gen l`j'`var'=l`j'.`var'/`var'
}

*sample median with interquartile range 
forvalues j=0/4{
egen `var'_f`j'_median=pctile(f`j'`var') if xsample==1, p(50)
egen `var'_f`j'_p25=pctile(f`j'`var') if xsample==1, p(25) 
egen `var'_f`j'_p75=pctile(f`j'`var') if xsample==1, p(75) 
}

*median after crisis with high capital
forvalues j=0/4{
egen `var'_f`j'_High=pctile(f`j'`var') if hi_sample==1, p(50) 
}

*median after crisis with low capital
forvalues j=0/4{
egen `var'_f`j'_Low=pctile(f`j'`var') if hi_sample==0 , p(50)
}

*sample median with interquartile range 
forvalues j=0/4{
egen `var'_l`j'_median=pctile(l`j'`var') if xsample==1, p(50)
egen `var'_l`j'_p25=pctile(l`j'`var') if xsample==1, p(25) 
egen `var'_l`j'_p75=pctile(l`j'`var') if xsample==1, p(75) 
}

*median before crisis with high capital
forvalues j=0/4{
egen `var'_l`j'_High=pctile(l`j'`var') if hi_sample==1 , p(50)
}

*median before crisis with low capital
forvalues j=0/4{
egen `var'_l`j'_Low=pctile(l`j'`var') if hi_sample==0 , p(50)
}


local measures p25 p75 median High Low

foreach x of local measures{

*Fill in values 
forvalues j=0/4{
egen `var'_f`j'_`x'1=mean(`var'_f`j'_`x') 
replace `var'_f`j'_`x' = `var'_f`j'_`x'1
}
forvalues j=0/4{
egen `var'_l`j'_`x'1=mean(`var'_l`j'_`x') 
replace `var'_l`j'_`x' = `var'_l`j'_`x'1
}
}

keep if iso=="USA" & year>=2003 & year<=2011
sort ccode year

gen sample_year=year-2007

foreach x of local measures{
replace `x'= `var'_l4_`x' if year==2003
replace `x'= `var'_l3_`x' if year==2004
replace `x'= `var'_l2_`x' if year==2005
replace `x'= `var'_l1_`x' if year==2006
replace `x'= `var'_f0_`x' if year==2007
replace `x'= `var'_f1_`x' if year==2008
replace `x'= `var'_f2_`x' if year==2009
replace `x'= `var'_f3_`x' if year==2010
replace `x'= `var'_f4_`x' if year==2011
}


keep if iso=="USA" & year>=2003 & year<=2011

label var sample_year "Year"

twoway  (rarea p25 p75 sample_year, ///
		fcolor(gs12) lcolor(white) lpattern(solid)) /// 
		(line median sample_year, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line High sample_year, lcolor(green) lpattern(longdash) lwidth(thick)) ///
		(line Low sample_year, lcolor(red) lpattern(shortdash) lwidth(thick)), ///
		graphregion(color(white)) plotregion(color(white)) ///
		xlabel(-4(1)4, nogrid) ylabel(0.7(0.1)1.2, nogrid) graphregion(color(white)) plotregion(color(white)) ///
		title("`p`var''", size(medlarge)) xtitle("Year", size(medlarge)) ///
		name(cris_`var', replace) legend(size(medsmall) pos(7) ring(0) col(1) region(ls(none)) order(2 1 3 4) label(1 "25th/75th percentile") label(2 "Median") label(3 "High-capital median") label(4 "Low-capital median"))
restore
}


local pbxreturns Returns
local vars bxreturns

foreach var of local vars{

preserve

*empty variables
gen High=.
gen Low=.
gen median=.
gen p25=.
gen p75=.


*Define sample: leads and lags  + capital ratio available
reg l(1/4).`var' f(0/4).`var' lev_1 if crisisJST==1 & war==0 & `c1'
cap drop xsample
gen xsample=e(sample)


*split at sample median of capital ratio
egen median_lev = pctile(lev_1) if xsample==1, p(50)
gen hi_sample=.
replace hi_sample=0 if xsample==1 & lev_1<=median_lev 
replace hi_sample=1 if xsample==1 & lev_1>median_lev 

sort ccode year

*over the following 4 years, relative to today
forvalues j=1/4{
tsegen   f`j'`var'=rowtotal(f(1/`j').bxreturns, `j')
}

*over the previous 4 years, relative to today
forvalues j=0/4{
tsegen forward_`var'_l`j'=rowtotal(l(0/`j').bxreturns, `j')
gen  l`j'`var'=-f.forward_`var'_l`j'
}


*sample median with interquartile range 
forvalues j=1/4{
egen `var'_f`j'_median=pctile(f`j'`var') if xsample==1, p(50)
egen `var'_f`j'_p25=pctile(f`j'`var') if xsample==1, p(25) 
egen `var'_f`j'_p75=pctile(f`j'`var') if xsample==1, p(75) 
}

*median after crisis with high capital
forvalues j=1/4{
egen `var'_f`j'_High=pctile(f`j'`var') if hi_sample==1, p(50) 
}

*median after crisis with low capital
forvalues j=1/4{
egen `var'_f`j'_Low=pctile(f`j'`var') if hi_sample==0 , p(50)
}

*sample median with interquartile range 
forvalues j=0/4{
egen `var'_l`j'_median=pctile(l`j'`var') if xsample==1, p(50)
egen `var'_l`j'_p25=pctile(l`j'`var') if xsample==1, p(25) 
egen `var'_l`j'_p75=pctile(l`j'`var') if xsample==1, p(75) 
}

*median before crisis with high capital
forvalues j=0/4{
egen `var'_l`j'_High=pctile(l`j'`var') if hi_sample==1 , p(50)
}

*median before crisis with low capital
forvalues j=0/4{
egen `var'_l`j'_Low=pctile(l`j'`var') if hi_sample==0 , p(50)
}


local measures p25 p75 median High Low

foreach x of local measures{

*Fill in values 
forvalues j=1/4{
egen `var'_f`j'_`x'1=mean(`var'_f`j'_`x') 
replace `var'_f`j'_`x' = `var'_f`j'_`x'1
}
forvalues j=0/4{
egen `var'_l`j'_`x'1=mean(`var'_l`j'_`x') 
replace `var'_l`j'_`x' = `var'_l`j'_`x'1
}
}

*=Plot
keep if iso=="USA" & year>=2003 & year<=2011
sort ccode year

gen sample_year=year-2007

foreach x of local measures{
replace `x'= `var'_l4_`x' if year==2003
replace `x'= `var'_l3_`x' if year==2004
replace `x'= `var'_l2_`x' if year==2005
replace `x'= `var'_l1_`x' if year==2006
replace `x'= 0			  if year==2007
replace `x'= `var'_f1_`x' if year==2008
replace `x'= `var'_f2_`x' if year==2009
replace `x'= `var'_f3_`x' if year==2010
replace `x'= `var'_f4_`x' if year==2011
}

keep if iso=="USA" & year>=2003 & year<=2011

label var sample_year "Year"

twoway  (rarea p25 p75 sample_year, ///
		fcolor(gs12) lcolor(white) lpattern(solid)) /// 
		(line median sample_year, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line High sample_year, lcolor(green) lpattern(longdash) lwidth(thick)) ///
		(line Low sample_year, lcolor(red) lpattern(shortdash) lwidth(thick)), ///
		graphregion(color(white)) plotregion(color(white)) ///
		xlabel(-4(1)4, nogrid) graphregion(color(white)) plotregion(color(white)) ///
		title("`p`var''", size(medlarge)) xtitle("Year", size(medlarge)) ///
		name(cris_`var', replace) legend(off)
restore
}

graph combine  cris_ltd cris_lev cris_loansgdp cris_bxreturns, ///
plotregion(color(white)) graphregion(color(white)) ///
ysize(4) xsize(10) col(4) name(cris3) scale(1.2)
		graph export "../graphs/Figure_4.pdf", replace
		graph export "../graphs/Figure_4.eps", replace

		graph drop _all
