****Binned bar charts of relationship between capital ratios and crisis risks/costs 

*Quintiles of capital ratio changes
egen dlev20 = pctile(dlev5), p(20)
egen dlev40 = pctile(dlev5), p(40)
egen dlev60 = pctile(dlev5), p(60)
egen dlev80 = pctile(dlev5), p(80)

gen dlev_quintile=.
replace dlev_quintile=1 if dlev5<=dlev20
replace dlev_quintile=2 if dlev5>dlev20 & dlev5 <= dlev40
replace dlev_quintile=3 if dlev5>dlev40 & dlev5 <= dlev60
replace dlev_quintile=4 if dlev5>dlev60 & dlev5 <= dlev80
replace dlev_quintile=5 if dlev5>dlev80 & dlev5 !=.

egen mean_crisis_dlev=mean(crisisJST), by(dlev_quintile)
replace mean_crisis_dlev=mean_crisis_dlev*100
twoway bar mean_crisis_dlev dlev_quintile, barwidth(.7) ///
			ylabel(0(2)6) graphregion(color(white)) plotregion(color(white)) ///
			ytitle("Financial crisis frequency in year t (%)", size(medsmall)) xtitle("Quintiles of capital ratio changes between year t-6 and t-1", size(medsmall)) ///
			scale(1.1)
			
		graph export "../graphs/Figure_6.pdf", replace
		graph export "../graphs/Figure_6.eps", replace


*Quintiles of capital ratio levels
egen lev20 = pctile(lev_1), p(20)
egen lev40 = pctile(lev_1), p(40)
egen lev60 = pctile(lev_1), p(60)
egen lev80 = pctile(lev_1), p(80)

gen lev_quintile=.
replace lev_quintile=1 if lev_1<=lev20
replace lev_quintile=2 if lev_1>lev20 & lev_1 <= lev40
replace lev_quintile=3 if lev_1>lev40 & lev_1 <= lev60
replace lev_quintile=4 if lev_1>lev60 & lev_1 <= lev80
replace lev_quintile=5 if lev_1>lev80 & lev_1 !=.

egen mean_crisis_lev=mean(crisisJST), by(lev_quintile)
replace mean_crisis_lev=mean_crisis_lev*100
twoway bar mean_crisis_lev lev_quintile, barwidth(.7) ///
			ylabel(0(2)8) graphregion(color(white)) plotregion(color(white)) ///
			ytitle("Financial crisis frequency in year t (%)", size(medsmall)) xtitle("Quintiles of capital ratio in year t-1", size(medsmall)) ///
			scale(0.8)
			
		graph export "../graphs/Figure_A5.pdf", replace
		graph export "../graphs/Figure_A5.eps", replace

		
*Crisis loss = equivalent to sum column in LPs		
gen crisis_cost=(f5.lrgdp-lrgdp)+(f4.lrgdp-lrgdp)+(f3.lrgdp-lrgdp)+(f2.lrgdp-lrgdp)+(f1.lrgdp-lrgdp)

gen lev_1_crisis=.
replace lev_1_crisis= lev_1 if pk_fin==1

egen lev20_crisis = pctile(lev_1_crisis), p(20)
egen lev40_crisis = pctile(lev_1_crisis), p(40)
egen lev60_crisis = pctile(lev_1_crisis), p(60)
egen lev80_crisis = pctile(lev_1_crisis), p(80)

gen lev_quintile_crisis=.
replace lev_quintile_crisis=1 if lev_1_crisis<=lev20_crisis
replace lev_quintile_crisis=2 if lev_1_crisis>lev20_crisis & lev_1_crisis <= lev40_crisis
replace lev_quintile_crisis=3 if lev_1_crisis>lev40_crisis & lev_1_crisis <= lev60_crisis
replace lev_quintile_crisis=4 if lev_1_crisis>lev60_crisis & lev_1_crisis <= lev80_crisis
replace lev_quintile_crisis=5 if lev_1_crisis>lev80_crisis & lev_1_crisis !=.

egen mean_crisis_cost=mean(crisis_cost) if pk_fin==1, by(lev_quintile_crisis)
twoway bar mean_crisis_cost lev_quintile_crisis , barwidth(.7) ///
			ylabel(-0.3(0.05)0.1) graphregion(color(white)) plotregion(color(white)) ///
			ytitle("Sum of cumulative real GDP changes t to t+5", size(medsmall)) xtitle("Quintiles of capital ratio in t-1", size(medsmall)) ///
			scale(0.8)
			
		graph export "../graphs/Figure_A6.pdf", replace
		graph export "../graphs/Figure_A6.eps", replace

graph drop _all
		
