
********************************************************************************
*Figure 1: Mean Leverage, interquartile range
********************************************************************************

preserve

replace lev=100*lev

sort year
by year: egen mlev=mean(lev)
by year: egen min=min(lev)
by year: egen max=max(lev)
by year: egen medlev=median(lev)
by year: egen P25=pctile(lev), p(25)
by year: egen P75=pctile(lev), p(75)

label var medlev "Median"
label var mlev "Mean"
rename min Min
rename max Max

sort iso year
keep if ccode==1 
twoway ///
	(rarea P25 P75 year, sort color(gs14)) ///
	(line mlev   year, lcolor(blue) lpattern(solid) lwidth(thick)  ) ///
	(line medlev year, lcolor(red)  lpattern(dash) lwidth(medthick)  )  ///
	if year<=2015 & year>=1870,  ///
	legend(pos(7) ring(0) col(1) region(ls(none)) order(2 3 1) label(2 "Mean") label(3 "Median") label(1 "25th/75th percentile range")) ///	
	xscale(r(1870 2015)) xlabel(1870 (10) 2010) ///
	xtitle("") ytitle("Capital ratio (%)")
	
graph display, ysize(3) xsize(6) scale(1.25)

graph export "../graphs/Figure_1.pdf" , replace
graph export "../graphs/Figure_1.eps" , replace
restore

********************************************************************************
*Figure 2: Mean Composition 
********************************************************************************

preserve
sort year

by year: egen mlev=mean(lev)
gen coreliabilities=(totcap+totdep)/totlia

sort year
by year: egen mcorelia=mean(coreliabilities)
gen x=1
replace x=x*100
replace mcorelia=mcorelia*100
replace mlev=mlev*100

sort iso year
keep if ccode==17 
twoway area x mcorelia mlev year ///
	if year<=2015 & year>=1870, col(red*0.6 pink*0.2 blue*0.6) ///
	legend(off) ///
	xscale(r(1870 2015)) xlabel(1870 (10) 2010)  ///
	xtitle("") ytitle("Share of total funding (%)") ///
	text(50 1940 "Deposits"             , place(e)  size(*1.1) ) ///
	text(10 1880 "Capital"              , place(e)  size(*1.1) ) ///
	text(85 1970 "Non-core liabilities" , place(e)  size(*1.1) )
	
graph display, ysize(3) xsize(6) scale(1.25)

graph export "../graphs/Figure_2.pdf" , replace
graph export "../graphs/Figure_2.eps" , replace

restore

********************************************************************************
*Figure 3: Mean LtD and interquartile range
********************************************************************************
preserve
sort year

replace ltd=ltd*100

by year: egen mltd=mean(ltd)
by year: egen medltd=median(ltd)
by year: egen P25=pctile(ltd), p(25)
by year: egen P75=pctile(ltd), p(75)

label variable mltd "Mean"
label variable medltd "Median"

sort iso year
keep if ccode==1 

twoway ///
	(rarea P25 P75 year, sort color(gs14)) ///
	(line mltd year, lcolor(blue) lwidth(thick))  ///
	(line medltd year, lcolor(red)  lpattern(dash) lwidth(medthick)  )  ///
	if year<=2015 & year>=1870,  ///
	xscale(r(1870 2015)) xlabel(1870 (10) 2010)  ///
	legend(pos(7) ring(0) col(1) region(ls(none)) order(2 3 1) label(2 "Mean") label(3 "Median") label(1 "25th/75th percentile range")) ///	
	xtitle("") ytitle("LtD ratio (%)")
	
graph display, ysize(3) xsize(6) scale(1.25)

graph export "../graphs/Figure_3.pdf" , replace
graph export "../graphs/Figure_3.eps" , replace
restore



********************************************************************************
*Appendix: Ratios for all countries
********************************************************************************

*A1: Leverage Ratio, full sample
preserve 
replace lev=lev*100

line lev year, by(iso, cols(3) note("") ) ///
	ytitle("Capital ratio (%)", size(vsmall)) xtitle("") note("") ///
	tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 1943 1944 1945, lc(ltbluishgray )) ///
	lw(thick) lc(green) ms(i) cmissing(n)  ///
	ttick(1870(20)2015) tlabel(1870(20)2015, alternate) yscale(r(0 50)) ylabel(0(25)50)

graph display, ysize(8) xsize(6)  scale(1.25)

graph export "../graphs/Figure_A1.pdf" , replace 
graph export "../graphs/Figure_A1.eps" , replace 
restore


*A2: Leverage Ratio, post 1945
preserve 
replace lev=lev*100
keep if year>1945

line lev year, by(iso, cols(3) note("") ) ///
	ytitle("Capital ratio (%)", size(vsmall)) xtitle("") note("") ///
	lw(thick) lc(green) ms(i) cmissing(n)  ///
	ttick(1945(10)2015) tlabel(1945(10)2015, alternate) yscale(r(0 15)) ylabel(0(5)15)

graph display, ysize(8) xsize(6)  scale(1.25)

graph export "../graphs/Figure_A2.pdf" , replace 
graph export "../graphs/Figure_A2.eps" , replace 
restore


*A3: Noncore Funding Ratio post 1945
preserve 
replace noncore=100*noncore
keep if year>1945

line noncore year, by(iso, cols(3) note("") ) ///
	ytitle("Non-core ratio (%)"  , size(vsmall) ) xtitle("") note("") ///
	lw(thick) lc(green) ms(i) cmissing(n)  ///
	ttick(1945(10)2015) tlabel(1945(10)2015, alternate) 
	
graph display, ysize(8) xsize(6) scale(1.25)

graph export "../graphs/Figure_A3.pdf" , replace 
graph export "../graphs/Figure_A3.eps" , replace 
restore


*A4: Loan-to-Deposit ratio, full sample
preserve 
replace ltd=100*ltd

line ltd year, by(iso, cols(3) note("") ) ///
	ytitle("LtD ratio (%)"  , size(vsmall) ) xtitle("") note("") ///
	tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 1943 1944 1945, lc(ltbluishgray )) ///
	lw(thick) lc(pink) ms(i) cmissing(n)  ///
	ttick(1870(20)2015) tlabel(1870(20)2010, alternate ) ylabel(, alternate)

graph display, ysize(8) xsize(6) scale(1.25)

graph export "../graphs/Figure_A4.pdf" , replace 
graph export "../graphs/Figure_A4.eps" , replace 
restore
