*Probit using BVX 2020 crisis dates

preserve

local c1 year >= 1870 
local c2 year > 1945 

local p1 full
local p2 post

*sets of control variables
local vol vol_dlrgdp_5 vol_dlcpi_5 vol_stir_5 dlcpi5 dlrgdp5 stir5 vol_dloansgdp_5
local bank_returns l(2/3).bank_return bank_return_1
local assets dlrhouses5 vol_dlrhouses_5 

local changevars lev_1 dlev5 

foreach change of local changevars{

*loop over time period
forvalues j=1/2{

	*Determine sample
	qui probit crisisBVX `change' dloansgdp5   ccode* ///
		if `c`j'' & war==0, cluster(iso)
		capture drop xsample
		qui gen xsample = e(sample)
			
	cap drop ysample
	
	probit crisisBVX `change' dloansgdp5 ccode1-ccode17 if xsample==1, cluster(iso)
	gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisBVX temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
	eststo m1_`j'_`change'
	cap drop ysample

	probit crisisBVX `change' dloansgdp5 `vol' ccode1-ccode17  if xsample==1 , cluster(iso)
	gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisBVX temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
	eststo m2_`j'_`change'
	cap drop ysample
	
	probit crisisBVX `change' dloansgdp5 `vol'  `assets' ccode1-ccode17 if xsample==1 , cluster(iso)
	gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisBVX temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
	eststo m3_`j'_`change'
	cap drop ysample
	
	probit crisisBVX `change' dloansgdp5 `vol' `bank_returns' `assets' ccode1-ccode17 if xsample==1 , cluster(iso)
	gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisBVX temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
	eststo m4_`j'_`change'
	cap drop ysample
	

	}
	}

	

	*Full and post-WW2 sample
	esttab m1_1_lev_1 m4_1_lev_1 m1_2_lev_1 m4_2_lev_1 m1_1_dlev5 m4_1_dlev5 m1_2_dlev5 m4_2_dlev5     ///
	using "../tables/Table_A23.tex", replace label ///
	keep(dloansgdp5 lev_1  dlev5 ) ///
	order(dloansgdp5 lev_1 dlev5 ) ///
	scalars( AUC se) margin se eqlabels(none) mtitles("Full" "Full" "Post" "Post" "Full" "Full" "Post" "Post") ///	
	indicate("Macrocontrols=vol_dlrgdp_5" "House Price Changes=dlrhouses5" "Bank Returns=bank_return_1") ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)

	
eststo clear
restore
