
local c1 year >= 1870
local c2 year < 1914  
local c3 year > 1945 

local p1 full
local p2 pre
local p3 post


*loop over time period
forvalues j=1/3{

	cap drop baseline
	cap drop noloans
	cap drop nolev
	cap drop nononcore

	qui probit crisisJST dloansgdp5 lev_1 noncore_1 ccode* ///
		if `c`j'' & war==0, cluster(iso)
		capture drop xsample
		qui gen xsample = e(sample)

	*Baseline, all + FE
	probit crisisJST dloansgdp5 lev_1 noncore_1 ccode* ///
	if xsample==1, cluster(iso)	
	eststo baseline_`p`j''
	predict baseline if xsample==1, xb
		roctab crisisJST baseline if xsample==1
		estadd scalar AUCr = r(area)

	*Drop loans
	probit crisisJST lev_1 noncore_1 ccode* ///
	if xsample==1, cluster(iso)	
	eststo loans_`p`j''
	predict noloans if xsample==1, xb
		roctab crisisJST noloans if xsample==1
		estadd scalar AUCr = r(area)
		roccomp crisisJST baseline noloans if xsample==1
		estadd scalar Pvalue = r(p)
		
	*Drop leverage 
	probit crisisJST dloansgdp5 noncore_1 ccode* ///
	if xsample==1, cluster(iso)	
	eststo lev_`p`j''
	predict nolev if xsample==1, xb
		roctab crisisJST nolev if xsample==1
		estadd scalar AUCr = r(area)
		roccomp crisisJST baseline nolev if xsample==1
		estadd scalar Pvalue = r(p)

	*Drop noncore
	probit crisisJST dloansgdp5 lev_1 ccode* ///
	if xsample==1, cluster(iso)	
	eststo noncore_`p`j''
	predict nononcore if xsample==1, xb
		roctab crisisJST nononcore if xsample==1
		estadd scalar AUCr = r(area)
		roccomp crisisJST baseline nononcore if xsample==1
		estadd scalar Pvalue = r(p)	
	}	

esttab baseline_full loans_full lev_full noncore_full ///
				using "../tables/Table_A16.tex", replace f ///
				drop(dloansgdp5 lev_1 noncore_1 ccode* _cons) mtitle("Full" "No credit" "No leverage" "No noncore") nodepvar ///
				obslast nonum scalars("AUCr AUC" "Pvalue p-value")

esttab baseline_pre loans_pre lev_pre noncore_pre ///
				using "../tables/Table_A16.tex", append f ///
				drop(dloansgdp5 lev_1 noncore_1 ccode* _cons) mtitle("Full" "No credit" "No leverage" "No noncore") nodepvar ///
				obslast nonum scalars("AUCr AUC" "Pvalue p-value")

esttab baseline_post loans_post lev_post noncore_post ///
				using "../tables/Table_A16.tex", append f ///
				drop(dloansgdp5 lev_1 noncore_1 ccode* _cons) mtitle("Full" "No credit" "No leverage" "No noncore") nodepvar ///
				obslast nonum scalars("AUCr AUC" "Pvalue p-value")
	
eststo clear
	