preserve

local c1 year >= 1870 
local c3 year > 1945 

local vol vol_dlrgdp_5 vol_dlcpi_5 vol_stir_5 dlcpi5 dlrgdp5 stir5 vol_dloansgdp_5 
local bank_returns l(2/3).bank_return bank_return_1 
local assets dlrhouses5 vol_dlrhouses_5

local controls `vol' `bank_returns' `assets'


********************************************************************************
*Hi/Lo interactions
********************************************************************************


forvalues j=1(2)3{

qui probit crisisJST lev_1 dloansgdp5 ccode1-ccode17 ///
if `c`j'' & war==0, cluster(iso)
	capture drop xsample
	qui gen xsample = e(sample)

cap drop lev_1_p50
cap drop lev_1_Hi

egen lev_1_p50=pctile(lev_1) if xsample==1, p(50)
gen lev_1_Hi=.
replace lev_1_Hi=0 if xsample==1
replace lev_1_Hi=1 if lev_1>=lev_1_p50 & xsample==1

cap drop inter
gen inter=dloansgdp5*lev_1_Hi
	
probit crisisJST dloansgdp5 lev_1_Hi inter ccode1-ccode17 ///
if xsample==1, cluster(iso)
predict temp if xsample==1, xb
margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo m1_`j'
	drop temp
	}
	
forvalues j=1(2)3{

qui probit crisisJST lev_1 dloansgdp5 `controls' ccode1-ccode17 ///
if `c`j'' & war==0, cluster(iso)
	capture drop xsample
	qui gen xsample = e(sample)

cap drop lev_1_p50
cap drop lev_1_Hi

egen lev_1_p50=pctile(lev_1) if xsample==1, p(50)
gen lev_1_Hi=.
replace lev_1_Hi=0 if xsample==1
replace lev_1_Hi=1 if lev_1>=lev_1_p50 & xsample==1

cap drop inter
gen inter=dloansgdp5*lev_1_Hi
	
probit crisisJST dloansgdp5 lev_1_Hi inter `controls' ccode1-ccode17 ///
if xsample==1, cluster(iso)
predict temp if xsample==1, xb
margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo m2_`j'
	drop temp


	}
	

	
*Same with Market-Leverage

forvalues j=1/1{

qui probit crisisJST marketlev_1 dloansgdp5 `controls' ccode1-ccode17 ///
if `c`j'' & war==0, cluster(iso)
	capture drop xsample
	qui gen xsample = e(sample)	

cap drop marketlev_1_p50
cap drop marketlev_1_Hi

egen marketlev_1_p50=pctile(marketlev_1) if xsample==1, p(50)
gen marketlev_1_Hi=.
replace marketlev_1_Hi=0 if  xsample==1
replace marketlev_1_Hi=1 if  marketlev_1>=marketlev_1_p50 & xsample==1


cap drop inter
gen inter=dloansgdp5*marketlev_1_Hi

probit crisisJST dloansgdp5 marketlev_1_Hi inter ccode1-ccode17 ///
if xsample==1, cluster(iso)
predict temp if xsample==1, xb
margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo m3_`j'
	drop temp
	
probit crisisJST dloansgdp5 marketlev_1_Hi inter `controls' ccode1-ccode17 ///
if xsample==1, cluster(iso)
predict temp if xsample==1, xb
margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo m4_`j'
	drop temp

}

label var marketlev_1_Hi "High capital (market-based)"
label var lev_1_Hi "High capital"
label var inter "$\Delta_5$ Loans/GDP x High capital"
 

*Interactions
esttab m1_1 m2_1 m1_3 m2_3 m3_1 m4_1  ///
	using "../tables/Table_A12.tex", replace label ///
	mtitles("Full" "Full" "Post" "Post"  "Post" "Post") ///
	keep(dloansgdp5 marketlev_1_Hi lev_1_Hi inter) ///
	order(dloansgdp5 lev_1_Hi marketlev_1_Hi inter) ///
	scalars(AUC se) indicate("Macro controls=vol_dlrgdp_5" "House price changes=dlrhouses5" "Excess stock returns=bank_return_1") ///
    margin se  nonotes wrap eqlabels(none)  ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs substitute(\_ _)

	restore
