********************************************************************************
*Instrumental variable probit (post-1945)
********************************************************************************

local c1  year > 1945 
local p1  post

local vol vol_dlrgdp_5 vol_dlcpi_5 vol_stir_5 dlcpi5 dlrgdp5 stir5 ///
vol_dloansgdp_5 dlrhouses5 vol_dlrhouses_5 l(2/3).bank_return bank_return_1


local pdroa5 5-year change in RoA
label var droa5 "5-year change in RoA"

********************************************************************************
*First Stage
********************************************************************************

forvalues j=1/1{
xtprobit crisisJST droa5 dlev5 dloansgdp5 ccode* if war==0 & `c`j''
cap drop xsample
gen xsample=e(sample)
xtreg dlev5 droa5 dloansgdp5 if xsample==1, fe 
estadd scalar Fstat = e(F)
eststo first_`p`j''
}

*First Stage Table
/*
esttab first_post ///
	using "../tables/IV_first_droa.tex", replace label ///
	keep(droa5 dloansgdp5) order(droa5 dloansgdp5) mtitles("Post")  ///
	r2 scalars(Fstat) booktabs nonotes substitute(\_ _) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) 
*/	

	
	
********************************************************************************
*Non-instrumented probit for comparison, only loans as control
********************************************************************************

forvalues j=1/1{
xtprobit crisisJST droa5 dlev5 dloansgdp5 ccode*  if war==0 & `c`j'', vce(cluster ccode)
cap drop xsample
gen xsample=e(sample)
xtprobit crisisJST dlev5 dloansgdp5 ccode* if xsample==1, vce(cluster ccode)
predict temp if xsample==1, xb
margins, dydx(dlev5 dloansgdp5) atmeans post
roctab crisisJST temp
estadd scalar AUC = r(area)
estadd scalar se = r(se)
drop temp
eststo no_inst_`p`j''_nobx
}


********************************************************************************
*No-capital probit for comparison, only loans as control
********************************************************************************

forvalues j=1/1{
xtprobit crisisJST droa5 dlev5 dloansgdp5 ccode* if war==0 & `c`j'', vce(cluster ccode)
cap drop xsample
gen xsample=e(sample)
xtprobit crisisJST dloansgdp5 ccode* if xsample==1, vce(cluster ccode) 
predict temp if xsample ==1, xb
margins , dydx( dloansgdp5) atmeans post
roctab crisisJST temp
estadd scalar AUC = r(area)
estadd scalar se = r(se)
drop temp
eststo no_lev_`p`j''_nobx
}


	
********************************************************************************
*Instrument, only loans as control
********************************************************************************

forvalues j=1/1{
ivprobit crisisJST (dlev5=droa5) dloansgdp5 ccode* if war==0 & `c`j'', vce(cluster ccode) 
cap drop xsample
gen xsample=e(sample)
predict temp if xsample ==1, xb
margins , dydx(dlev5 dloansgdp5) atmeans post pred(pr)
roctab crisisJST temp
estadd scalar AUC = r(area)
estadd scalar se = r(se)
drop temp
eststo instrumented_`p`j''_nobx
}

********************************************************************************
*Non-instrumented probit for comparison, controls
********************************************************************************

forvalues j=1/1{
xtprobit crisisJST droa5 dlev5 dloansgdp5 `vol'  ccode*  if war==0 & `c`j'', vce(cluster ccode)
cap drop xsample
gen xsample=e(sample)
xtprobit crisisJST dlev5 dloansgdp5 `vol' ccode* if xsample==1, vce(cluster ccode)
predict temp if xsample==1, xb
margins, dydx(dlev5 dloansgdp5 `vol') atmeans post
roctab crisisJST temp
estadd scalar AUC = r(area)
estadd scalar se = r(se)
drop temp
eststo no_inst_`p`j''
}


********************************************************************************
*No-capital probit for comparison, controls
********************************************************************************

forvalues j=1/1{
xtprobit crisisJST droa5 dlev5 dloansgdp5 `vol'  ccode* if war==0 & `c`j'', vce(cluster ccode)
cap drop xsample
gen xsample=e(sample)
xtprobit crisisJST dloansgdp5 `vol'  ccode* if xsample==1, vce(cluster ccode) 
predict temp if xsample ==1, xb
margins , dydx(dloansgdp5 `vol') atmeans post
roctab crisisJST temp
estadd scalar AUC = r(area)
estadd scalar se = r(se)
drop temp
eststo no_lev_`p`j''
}


	
********************************************************************************
*Instrument, controls
********************************************************************************

forvalues j=1/1{
ivprobit crisisJST (dlev5=droa5) dloansgdp5 `vol'  ccode* if war==0 & `c`j'', vce(cluster ccode) 
cap drop xsample
gen xsample=e(sample)
predict temp if xsample ==1, xb
margins , dydx(dlev5 dloansgdp5 `vol') atmeans post pred(pr)
roctab crisisJST temp
estadd scalar AUC = r(area)
estadd scalar se = r(se)
drop temp
eststo instrumented_`p`j''
}


esttab no_lev_post_nobx no_inst_post_nobx instrumented_post_nobx no_lev_post no_inst_post instrumented_post ///
	using "../tables/Table_A24.tex", replace label ///
	keep(dlev5 dloansgdp5) order(dloansgdp5  dlev5) mtitles("No Cap" "Cap" "IV" "No Cap" "Cap" "IV") booktabs nonotes substitute(\_ _) eqlabels(none) ///
	indicate("Asset risks=bank_return_1"  "Macrocontrols=vol_dlrgdp_5") scalars(AUC se) b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01)

eststo clear


********************************************************************************
*First Stage Binscatter
********************************************************************************

binscatter dlev5 droa5 if war==0 & year>1945, nquantiles(20)  ///
	mcolor(black) ///
	ylabel(, nogrid) ///
	ytitle("5-year average annual change in capital ratio", size(medium)) ///
	xtitle("5-year average annual change in RoA", size(medium)) ///
	graphregion(color(white) margin(small)) aspectratio(0.8) ///
	name(post, replace) 
   graph export  "../graphs/Figure_A8.pdf" , replace
   graph export  "../graphs/Figure_A8.eps" , replace
graph close _all  


