*Define time periods and samples
local c1 year >= 1870
local c2 year < 1914
local c3 year > 1945 
local c4 year < 2007
local c5 year >= 1870 & iso!="GBR" & iso!="USA"
local c6 year > 1945 & iso!="GBR" & iso!="USA"

local p1 full
local p2 pre
local p3 post
local p4 noGFC
local p5 fnoUS
local p6 pnoUS

*label important variables
label variable dlev5 "$\Delta_5$ Capital ratio"
label variable dltd5 "$\Delta_5$ LtD"
label variable dnoncore5 "$\Delta_5$ Non-core ratio"
label variable dliagdp5 "$\Delta_5$ Assets/GDP"
label variable dloansgdp5 "$\Delta_5$ Loans/GDP"
label variable lev_1 "Capital ratio"
label variable ltd_1 "LtD ratio"
label variable noncore_1 "Non-core ratio"
label variable marketlev_1 "Market-based capital ratio"
label variable dmarketlev5 "$\Delta_5$ Market-based capital ratio"

********************************************************************************
*Probit main (models for Table 4 and Appendix Tables)
********************************************************************************

*Changes and levels of balance sheet variables
local changevars lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5

*With and w/o country FEs
local FE1 ccode1-ccode17
local FE2

forvalues k=1/2{						// with and without FEs
forvalues j=1/6{						// sample: subperiods and excluding US/UK
foreach change of local changevars{		// foreach balance sheet ratio

	cap drop baseline
	cap drop loansmodel

	*Baseline, only balance sheet ratio
	probit crisisJST `change' `FE`k'' if `c`j'' & war==0, cluster(iso)
	cap drop xsample
	gen xsample=e(sample)	
	predict baseline if xsample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisJST baseline if xsample==1
		estadd scalar AUCr = r(area)
		estadd scalar se = r(se)
		eststo uni_`change'_`p`j''_FE`k'

	*Including changes in credit/GDP
	probit crisisJST dloansgdp5 `change' `FE`k'' if `c`j'' & war==0, cluster(iso)
	cap drop xsample
	gen xsample=e(sample)
	predict loansmodel if xsample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisJST loansmodel if xsample==1
		estadd scalar AUCr = r(area)
		estadd scalar se = r(se)
		eststo loans_`change'_`p`j''_FE`k'

}
}	
}


*Table 4
	esttab loans_lev_1_full_FE1 loans_lev_1_post_FE1 loans_dlev5_full_FE1 loans_dlev5_post_FE1 loans_ltd_1_full_FE1 loans_ltd_1_post_FE1 loans_noncore_1_full_FE1 loans_noncore_1_post_FE1 ///
	using "../tables/Table_4.tex", replace label ///
	keep(dloansgdp5 lev_1 dlev5 ltd_1 noncore_1) scalars(AUCr se) margin se eqlabels(none)  ///
	order(dloansgdp5 lev_1 dlev5 ltd_1 noncore_1) ///
	mtitles("Full" "Post" "Full" "Post" "Full" "Post" "Full" "Post") ///	
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)	
	
*Appendix Table Full Sample, no controls
esttab uni_lev_1_full_FE1 uni_dlev5_full_FE1 uni_ltd_1_full_FE1 uni_dltd5_full_FE1 uni_noncore_1_full_FE1 uni_dnoncore5_full_FE1 ///
	using "../tables/Table_A13.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)
	
*Appendix Table Post-1945 Sample, no controls
esttab uni_lev_1_post_FE1 uni_dlev5_post_FE1 uni_ltd_1_post_FE1 uni_dltd5_post_FE1 uni_noncore_1_post_FE1 uni_dnoncore5_post_FE1 ///
	using "../tables/Table_A14.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)
	
*Appendix Table Pre-1914, no controls
esttab uni_lev_1_pre_FE1 uni_dlev5_pre_FE1 uni_ltd_1_pre_FE1 uni_dltd5_pre_FE1 uni_noncore_1_pre_FE1 uni_dnoncore5_pre_FE1 ///
	using "../tables/Table_A15.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)

*Appendix Table Full Sample, no FE
esttab uni_lev_1_full_FE2 uni_dlev5_full_FE2 uni_ltd_1_full_FE2 uni_dltd5_full_FE2 uni_noncore_1_full_FE2 uni_dnoncore5_full_FE2 ///
	using "../tables/Table_A17.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)
		
*Appendix Table Post-1945 Sample, no FE
esttab uni_lev_1_post_FE2 uni_dlev5_post_FE2 uni_ltd_1_post_FE2 uni_dltd5_post_FE2 uni_noncore_1_post_FE2 uni_dnoncore5_post_FE2 ///
	using "../tables/Table_A18.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)
	
*Appendix Table, no post 2006 data
esttab uni_lev_1_noGFC_FE1 uni_dlev5_noGFC_FE1 uni_ltd_1_noGFC_FE1 uni_dltd5_noGFC_FE1 uni_noncore_1_noGFC_FE1 uni_dnoncore5_noGFC_FE1 ///
	using "../tables/Table_A19.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)

*Appendix Table Full sample, excluding US and UK
esttab uni_lev_1_fnoUS_FE1 uni_dlev5_fnoUS_FE1 uni_ltd_1_fnoUS_FE1 uni_dltd5_fnoUS_FE1 uni_noncore_1_fnoUS_FE1 uni_dnoncore5_fnoUS_FE1 ///
	using "../tables/Table_A20.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)
	
*Appendix Table Post-1945 sample, excluding US and UK
esttab uni_lev_1_pnoUS_FE1 uni_dlev5_pnoUS_FE1 uni_ltd_1_pnoUS_FE1 uni_dltd5_pnoUS_FE1 uni_noncore_1_pnoUS_FE1 uni_dnoncore5_pnoUS_FE1 ///
	using "../tables/Table_A21.tex", replace label ///
	keep(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) scalars( AUCr se) margin se  eqlabels(none)  ///
	order(lev_1 dlev5 ltd_1 dltd5 noncore_1 dnoncore5) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)
		
eststo clear


********************************************************************************
*Table 5 
********************************************************************************	
gen bank_return_2=l2.bank_return
gen bank_return_3=l3.bank_return

*sets of control variables 
local macrovol vol_dlrgdp_5 vol_dlcpi_5 vol_stir_5 dlcpi5 dlrgdp5 stir5 vol_dloansgdp_5
local assets bank_return_3 bank_return_2 bank_return_1 dlrhouses5 vol_dlrhouses_5 

local levvars lev_1 dlev5 
	
foreach change of local levvars{

*loop over time period
forvalues j=1(2)3{

	probit crisisJST `change' dloansgdp5 `macrovol' ccode1-ccode17 if `c`j'' & war==0, cluster(iso)
	gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisJST temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
	eststo m1_`j'_`change'
	cap drop ysample
	
	probit crisisJST `change' dloansgdp5 `macrovol' `assets' ccode1-ccode17 if `c`j'' & war==0, cluster(iso)
	gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisJST temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
	eststo m2_`j'_`change'
	cap drop ysample
	}
	}

	esttab m1_1_lev_1 m2_1_lev_1 m1_3_lev_1 m2_3_lev_1 m1_1_dlev5 m2_1_dlev5 m1_3_dlev5 m2_3_dlev5     ///
	using "../tables/Table_5.tex", replace label ///
	keep(dloansgdp5 lev_1  dlev5 ) ///
	order(dloansgdp5 lev_1 dlev5 ) ///
	scalars( AUC se) margin se eqlabels(none) mtitles("Full" "Full" "Post" "Post" "Full" "Full" "Post" "Post") ///	
	indicate("Macrocontrols=vol_dlrgdp_5" "Asset prices=dlrhouses5") ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)

eststo clear



********************************************************************************
*Probit models 2-way clustering: Table 4 
********************************************************************************


forvalues j=1(2)3{						// sample, subperiods 
foreach change of local changevars{		// foreach variable

	probit2 crisisJST dloansgdp5 `change' ccode1-ccode17 if `c`j'' & war==0, fcluster(iso) tcluster(year)
	eststo loa_`change'_`p`j''_2way

}
}	


qui file open table_out using "..\tables\Table_A6.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{9}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out " \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9}  " _n
	file write table_out " & Full & Post  & Full & Post  & Full & Post & Full & Post  \\ \midrule " _n
	file close table_out

	*Table 4 - 2way - no marginal effects
	esttab loa_lev_1_full_2way loa_lev_1_post_2way loa_dlev5_full_2way loa_dlev5_post_2way loa_ltd_1_full_2way loa_ltd_1_post_2way loa_noncore_1_full_2way loa_noncore_1_post_2way ///
	using "..\tables\Table_A6.tex", f append ///
		   keep(dloansgdp5 lev_1 dlev5 ltd_1 noncore_1 ) ///
		   order(dloansgdp5 lev_1 dlev5 ltd_1 noncore_1 ) ///
		   compress b(%8.2f) se(%8.2f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   booktabs eqlabels(none)  substitute(\_ _)  nonotes ///
		   nomtitles label collabels(none) nonum 	

qui file open table_out using "..\tables\Table_A6.tex", write append
	file write table_out "\midrule\bottomrule" _n
	file write table_out "\end{tabularx}" _n
	file close table_out


********************************************************************************
*Probit models 2-way clustering of Table 5
********************************************************************************

cap drop predictvar
gen predictvar=.

forvalues j=1(2)3{						// sample, subperiods 
foreach change of local levvars{		// foreach variable
				
	probit2 crisisJST dloansgdp5 `change' `macrovol' ccode1-ccode17 if `c`j'' & war==0, fcluster(iso) tcluster(year)
	eststo vol_`change'_`p`j''_2way
	
	probit2 crisisJST dloansgdp5 `change' `macrovol' `assets' ccode1-ccode17 if `c`j'' & war==0, fcluster(iso) tcluster(year)
	eststo ass_`change'_`p`j''_2way
}
}	

qui file open table_out using "..\tables\Table_A7.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{9}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out " & \multicolumn{2}{c}{Full sample} & \multicolumn{2}{c}{Post-WW2 sample} & \multicolumn{2}{c}{Full sample} & \multicolumn{2}{c}{Post-WW2 sample}   \\ " _n
	file write table_out " \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9}  " _n	
	file close table_out

	esttab vol_lev_1_full_2way ass_lev_1_full_2way vol_lev_1_post_2way ass_lev_1_post_2way vol_dlev5_full_2way ass_dlev5_full_2way vol_dlev5_post_2way ass_dlev5_post_2way   ///
	using "..\tables\Table_A7.tex", f append ///
		   keep(dloansgdp5 lev_1 dlev5) ///
		   order(dloansgdp5 lev_1 dlev5) ///
		   compress b(%8.2f) se(%8.2f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   booktabs eqlabels(none)  substitute(\_ _)  nonotes ///
		   nomtitles label collabels(none) nonum indicate(" Macrocontrols=vol_dlrgdp_5" "Asset risk=bank_return_3")	

qui file open table_out using "..\tables\Table_A7.tex", write append
	file write table_out "\midrule\bottomrule" _n
	file write table_out "\end{tabularx}" _n
	file close table_out

eststo clear
	



********************************************************************************
*Market-based capital ratio variables 
********************************************************************************

local changevars marketlev_1 dmarketlev5 
	
foreach var of local changevars{
	
	probit crisisJST `var' dloansgdp5  ccode1-ccode17 if `c1' & war==0, cluster(iso)
		cap drop ysample
		gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisJST temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
	eststo base_`var'
	
	*With controls (no control bank stock prices)	
	probit crisisJST `var' dloansgdp5 `macrovol' dlrhouses5 ccode1-ccode17 if `c1' & war==0, cluster(iso)
		cap drop ysample
		gen ysample=e(sample)
		predict temp if ysample==1
		margins, dydx(_all) at((mean) _all) post
		roctab crisisJST temp
		estadd scalar AUC = r(area)
		estadd scalar se = r(se)
		drop temp
		drop ysample
	eststo full_`var'

	}
	
	*Market based measures
	esttab  base_marketlev_1 full_marketlev_1  base_dmarketlev5 full_dmarketlev5    ///
	using "../tables/Table_A9.tex", replace label ///
	keep(dloansgdp5 marketlev_1  dmarketlev5 ) ///
	order(dloansgdp5 marketlev_1  dmarketlev5 ) ///
	scalars( AUC se) margin se eqlabels(none) nomtitles ///	
	indicate("Macrocontrols=vol_dlrgdp_5" "House Price Changes=dlrhouses5") ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes substitute(\_ _)
	
eststo clear
