*Prediction sample periods 
local c1 year >= 1870 & (year <1935 | year >1945)  & (year <1910 | year >1919) 

*= Generate cumulative return variables for h=1,2,3 years
gen cum_return_1=f.bxreturns
gen cum_return_2=f.bxreturns+f2.bxreturns
gen cum_return_3=f.bxreturns+f2.bxreturns+f3.bxreturns

*= Generate three year changes as predictors (as in BX2017)
local vars ltd lev noncore liagdp
foreach v of local vars{
gen d`v'3=`v'-l3.`v'
}

*=standardize at country level, using only past data as in BX2017
local tostandard dloansgdp3 dltd3 dlev3 dnoncore3 dliagdp3 lev bank_d_p 

foreach to of local tostandard{
	gen stdup_`to' =.
	forvalues j=1/17{
	forvalues i=1870(1)2015{
	
	qui sum `to' if ccode==`j' & year<=`i' 
	scalar mean_xt = r(mean)
	scalar std_xt = r(sd)
	replace stdup_`to'=(`to'-mean_xt)/std_xt if ccode==`j' & year==`i'
	}
	}
}


********************************************************************************
* Compute optimal bandwidth based on country level time series
********************************************************************************

gen bw=.

save "../data/temp.dta", replace

keep iso year 

save "../data/optimal_bandwidth.dta", replace

forvalues c=1/7{
	use "../data/temp.dta", clear
	keep if ccode == `c'
	tsset year, yearly
	ivreg2 cum_return_1 stdup_dloansgdp3, robust bw(auto)
	replace bw=e(bw) if ccode==`c'
	merge 1:1 iso year using "../data/optimal_bandwidth.dta", nogen
	keep iso year bw
	save "../data/optimal_bandwidth.dta", replace
}
// No return data for Finland
forvalues c=9/17{
	use "../data/temp.dta", clear
	keep if ccode == `c'
	tsset year, yearly
	ivreg2 cum_return_1 stdup_dloansgdp3, robust bw(auto)
	replace bw=e(bw) if ccode==`c'
	merge 1:1 iso year using "../data/optimal_bandwidth.dta", nogen
	keep iso year bw
	save "../data/optimal_bandwidth.dta", replace
}

keep if year == 2015
egen mean=mean(bw)

save "../data/optimal_bandwidth.dta", replace
use "../data/temp.dta",clear


********************************************************************************
*Results Tables
********************************************************************************
file close _all

eststo clear

local j 1 					// full sample only
local lag 17 				// mean of country level optimal bandwidth, see above

cap drop predictvar
gen predictvar=.			


foreach controlset in no yes{
forvalues v=1/3{

local no
local yes stdup_dloansgdp3 stdup_bank_d_p

replace predictvar=stdup_dloansgdp3
eststo cum_return_dloansgdp3_`v'_`controlset': xtscc cum_return_`v' predictvar ``controlset'' if `c`j'' & war==0, fe lag(`lag')

replace predictvar=stdup_dliagdp3
eststo cum_return_dliagdp3_`v'_`controlset':  xtscc cum_return_`v' predictvar ``controlset'' if `c`j'' & war==0, fe lag(`lag')

replace predictvar=stdup_dnoncore3
eststo cum_return_dnoncore3_`v'_`controlset': xtscc cum_return_`v' predictvar  ``controlset'' if `c`j'' & war==0, fe lag(`lag')

replace predictvar=stdup_lev
eststo cum_return_lev_`v'_`controlset': xtscc cum_return_`v' predictvar ``controlset'' if `c`j'' & war==0, fe lag(`lag')

replace predictvar=stdup_dlev3
eststo cum_return_dlev3_`v'_`controlset': xtscc cum_return_`v' predictvar ``controlset'' if `c`j'' & war==0, fe lag(`lag')

replace predictvar=stdup_dltd3
eststo cum_return_dltd3_`v'_`controlset': xtscc cum_return_`v' predictvar ``controlset'' if `c`j'' & war==0, fe lag(`lag')
}
}

label var stdup_dnoncore3 "$ \Delta_3 Noncore Ratio $"
label var stdup_dltd3 "$ \Delta_3 LtD Ratio $"
label var stdup_dlev3 "$ \Delta_3 Capital Ratio $"
label var stdup_lev "$ Capital Ratio $"
label var stdup_dliagdp3 "$ \Delta_3 Assets/GDP $"
label var stdup_dloansgdp3 "$ \Delta_3 Loans/GDP $"
label var stdup_bank_d_p "DP"
label var predictvar "See column header"
 
*quantities with controls
qui file open table_out using "..\tables\Table_6_PanelA.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{7}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out " & (1) & (2) & (3) & (4) & (5) & (6)  \\  " _n
	file write table_out "Cumulative returns & 1-year  & 2-year & 3-year  & 1-year & 2-year & 3-year  \\  " _n
	file write table_out "\midrule\midrule" _n
	file write table_out "Panel A & \multicolumn{3}{c}{RHS: $\Delta_3$ Loans/GDP} & \multicolumn{3}{c}{RHS: $\Delta_3$ Assets/GDP} \\ " _n
	file write table_out " \cmidrule(lr){2-4} \cmidrule(lr){5-7} " _n
	file close table_out
	
esttab cum_return_dloansgdp3_1_yes cum_return_dloansgdp3_2_yes cum_return_dloansgdp3_3_yes cum_return_dliagdp3_1_yes cum_return_dliagdp3_2_yes cum_return_dliagdp3_3_yes using "..\tables\Table_6_PanelA.tex", f append ///
		   keep(predictvar) ///
		   compress b(%8.3f) se(%8.3f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   scalars("r2_w \(R^2\)") ///
		   booktabs   substitute(\_ _) nonotes ///
		   obslast nomtitles label collabels(none) nonum 
	   
qui file open table_out using "..\tables\Table_6_PanelA.tex", write append
	file write table_out "\end{tabularx}" _n
	file close table_out

*quantities w/o controls

qui file open table_out using "..\tables\Table_A31_PanelA.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{7}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out " & (1) & (2) & (3) & (4) & (5) & (6)  \\  " _n
	file write table_out "Cumulative returns & 1-year  & 2-year & 3-year  & 1-year & 2-year & 3-year  \\  " _n
	file write table_out "\midrule\midrule" _n
	file write table_out "Panel A & \multicolumn{3}{c}{RHS: $\Delta_3$ Loans/GDP} & \multicolumn{3}{c}{RHS: $\Delta_3$ Assets/GDP} \\ " _n
	file write table_out " \cmidrule(lr){2-4} \cmidrule(lr){5-7} " _n
	file close table_out
	
esttab cum_return_dloansgdp3_1_no cum_return_dloansgdp3_2_no cum_return_dloansgdp3_3_no cum_return_dliagdp3_1_no cum_return_dliagdp3_2_no cum_return_dliagdp3_3_no using "..\tables\Table_A31_PanelA.tex", f append ///
		   keep(predictvar) ///
		   compress b(%8.3f) se(%8.3f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   scalars("r2_w \(R^2\)") ///
		   booktabs   substitute(\_ _) nonotes ///
		   obslast nomtitles label collabels(none) nonum 
	   
qui file open table_out using "..\tables\Table_A31_PanelA.tex", write append
	file write table_out "\end{tabularx}" _n
	file close table_out
	
	
*leverage with controls

qui file open table_out using "..\tables\Table_6_PanelB.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{7}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out "Panel B & \multicolumn{3}{c}{RHS: Capital ratio} & \multicolumn{3}{c}{RHS: $\Delta_3$ Capital ratio} \\ " _n
	file write table_out " \cmidrule(lr){2-4} \cmidrule(lr){5-7} " _n
	file close table_out
	
esttab cum_return_lev_1_yes cum_return_lev_2_yes cum_return_lev_3_yes cum_return_dlev3_1_yes cum_return_dlev3_2_yes cum_return_dlev3_3_yes using "..\tables\Table_6_PanelB.tex", f append ///
		   keep(predictvar) ///
		   compress b(%8.3f) se(%8.3f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   scalars("r2_w \(R^2\)") ///
		   booktabs   substitute(\_ _) nonotes ///
		   obslast nomtitles label collabels(none) nonum 
	   
qui file open table_out using "..\tables\Table_6_PanelB.tex", write append
	file write table_out "\end{tabularx}" _n
	file close table_out
	
*leverage w/o controls

qui file open table_out using "..\tables\Table_A31_PanelB.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{7}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out "Panel B & \multicolumn{3}{c}{RHS: Capital ratio} & \multicolumn{3}{c}{RHS: $\Delta_3$ Capital ratio} \\ " _n
	file write table_out " \cmidrule(lr){2-4} \cmidrule(lr){5-7} " _n
	file close table_out
	
esttab cum_return_lev_1_no cum_return_lev_2_no cum_return_lev_3_no cum_return_dlev3_1_no cum_return_dlev3_2_no cum_return_dlev3_3_no using "..\tables\Table_A31_PanelB.tex", f append ///
		   keep(predictvar) ///
		   compress b(%8.3f) se(%8.3f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   scalars("r2_w \(R^2\)") ///
		   booktabs   substitute(\_ _) nonotes ///
		   obslast nomtitles label collabels(none) nonum 
	   
qui file open table_out using "..\tables\Table_A31_PanelB.tex", write append
	file write table_out "\end{tabularx}" _n
	file close table_out
	
*liquidity with controls

qui file open table_out using "..\tables\Table_6_PanelC.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{7}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out "Panel C & \multicolumn{3}{c}{RHS: $\Delta_3$ LtD ratio} & \multicolumn{3}{c}{RHS: $\Delta_3$ Non-core ratio} \\ " _n
	file write table_out " \cmidrule(lr){2-4} \cmidrule(lr){5-7} " _n
	file close table_out
	
esttab cum_return_dltd3_1_yes cum_return_dltd3_2_yes cum_return_dltd3_3_yes cum_return_dnoncore3_1_yes cum_return_dnoncore3_2_yes cum_return_dnoncore3_3_yes using "..\tables\Table_6_PanelC.tex", f append ///
		   keep(predictvar) ///
		   compress b(%8.3f) se(%8.3f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   scalars("r2_w \(R^2\)") ///
		   booktabs   substitute(\_ _) nonotes ///
		   obslast nomtitles label collabels(none) nonum 
	   
qui file open table_out using "..\tables\Table_6_PanelC.tex", write append
	file write table_out "\midrule\bottomrule" _n
	file write table_out "\end{tabularx}" _n
	file close table_out
	
*liquidity w/o controls

qui file open table_out using "..\tables\Table_A31_PanelC.tex", write replace
	file write table_out "\vspace{0.15cm} \begin{tabularx}{\textwidth}{@{} l*{7}{C} @{}}" _n
	file write table_out "\midrule\midrule" _n
	file write table_out "Panel C & \multicolumn{3}{c}{RHS: $\Delta_3$ LtD ratio} & \multicolumn{3}{c}{RHS: $\Delta_3$ Non-core ratio} \\ " _n
	file write table_out " \cmidrule(lr){2-4} \cmidrule(lr){5-7} " _n
	file close table_out
	
esttab cum_return_dltd3_1_no cum_return_dltd3_2_no cum_return_dltd3_3_no cum_return_dnoncore3_1_no cum_return_dnoncore3_2_no cum_return_dnoncore3_3_no using "..\tables\Table_A31_PanelC.tex", f append ///
		   keep(predictvar) ///
		   compress b(%8.3f) se(%8.3f)  star(* 0.10 ** 0.05 *** 0.01 ) noconstant ///
		   scalars("r2_w \(R^2\)") ///
		   booktabs   substitute(\_ _) nonotes ///
		   obslast nomtitles label collabels(none) nonum 
	   
qui file open table_out using "..\tables\Table_A31_PanelC.tex", write append
	file write table_out "\midrule\bottomrule" _n
	file write table_out "\end{tabularx}" _n
	file close table_out

	

eststo clear
